/** \file sequencesMatrix.cpp
 * \brief \ref sequencesMatrix class method implementation.
 *
 * This file contains \ref sequencesyMatrix class methods implementation.
 */

#include "sequencesMatrix.h"


/*+++++++++++++++++++++++++++++++++++++++++++++++++++++
| sequencesMatrix::sequencesMatrix()                  |
|      Class constructor.                             |
|                                                     |
+++++++++++++++++++++++++++++++++++++++++++++++++++++*/

sequencesMatrix::sequencesMatrix(void) {

  matrix = NULL;

}


/*+++++++++++++++++++++++++++++++++++++++++++++++++++++
| sequencesMatrix::sequencesMatrix(char **, ..., ...) |
|      Class constructor.                             |
|                                                     |
+++++++++++++++++++++++++++++++++++++++++++++++++++++*/

sequencesMatrix::sequencesMatrix(char **alignmentMatrix, int species, int aminos) {

  int i, j, k;
	
  columnLength = aminos;
  columns = 	 species;

  matrix = new int*[columns];
  for(i = 0; i < columns; i++) { 
    matrix[i] = new int[columnLength];
    utils::initlVect(matrix[i], columnLength, 0);
  }

  /* Determinate the sequence for each alignment specie */
  for(i = 0; i < columns; i++, k = 1) {
    for(j = 0; j < columnLength; j++) {
      if(alignmentMatrix[i][j] != '-') {
        matrix[i][j] = k;
        k++;
      }
    }
  }

}


/*+++++++++++++++++++++++++++++++++++++++++++++++++++++
| sequencesMatrix::~sequencesMatrix()                 |
|      Class destructor.                              |
|                                                     |
+++++++++++++++++++++++++++++++++++++++++++++++++++++*/

sequencesMatrix::~sequencesMatrix(void) {

  int i;

  if(matrix != NULL) {
    for(i = 0; i < columnLength; i++) 
      delete[] matrix[i];
    delete[] matrix;
  }  
}


/*+++++++++++++++++++++++++++++++++++++++++++++++++++++
| void sequencesMatrix::printMatrix()                 |
|      This method prints the alignment sequences     |
|      matrix.                                        |
|                                                     |
+++++++++++++++++++++++++++++++++++++++++++++++++++++*/

void sequencesMatrix::printMatrix(void) {
  
  int i, j, k;

  for(i = 0; i < columnLength; i += 10) {
    for(j = 0; j < columns; j++) {		
      for(k = i; k < (10 + i) && k < columnLength; k++) {
        cout << setw(3) << matrix[j][k] << ' ';
      }
      cout << endl;
    }
    cout << endl;
  }  
}


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
| void sequencesMatrix::getColumn(int column, int *columnSeqMatrix)  |
|      This method stores the column "column" of sequences matrix in |
|      a vector.                                                     |
|                                                                    |
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

void sequencesMatrix::getColumn(int column, int *columnSeqMatrix) {

  for(int i = 0; i < columns; i++)
    columnSeqMatrix[i] = matrix[i][column];

}


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
| void sequencesMatrix::getColumn(int value, int row, int *columnSeqMatrix)  |
|      This method stores the column, with the "value" at the position       |
|      (column, "row"), of sequences matrix in a vector.                     |
|                                                                            |
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

void sequencesMatrix::getColumn(int value, int row, int *columnSeqMatrix) {
	
  int i, j;

  for(i = 0; i < columnLength; i++)
    if(matrix[row][i] == value) break;

  for(j = 0; j < columns; j++)
    columnSeqMatrix[j] = matrix[j][i];

}
