/** \file similarityMatrix.h
 * \brief File containing \ref similarityMatrix class definition.
 *
 * This file contains the \ref similarityMatrix class definition, with the
 * definition of its attributes and its methods.
 */

#ifndef SIMILARITYMATRIX_H
#define SIMILARITYMATRIX_H

/** \brief Class that implements a generic similarity matrix
 *
 * This class implements a similarity matrix with many options.
 * This class can store very kind of similarity matrix, with
 * a variety of simbols and a lot of them.
 */

class similarityMatrix{
  int *vhash;
  float **simMat;
  float **distMat;
  int numPositions;
  
  
 private:
  void memoryAllocation(int nPos);
  void memoryDeletion();
  
 public:
  /** \brief Class costructor.
   *
   * This constructor initializates all attributes to NULL or zero
   */
  similarityMatrix();

  /** \brief Class destructor.
   *
   * Class destructor. This destructor deletes dynamic memory allocation of
   * attributes.
   */
  ~similarityMatrix();

  /** \brief Loading matrix method.
   * \param fn Similarity matrix file name.
   * \return \e true if all is ok, \e false if there were errors (i.e. the file format is incorrect, file not exists...)
   *
   * This method loads a similarity matrix from a file.
   */
  bool loadSimMatrix(char *fn);

  /** \brief Getting distance method
   * \param a Symbol to calculate distance
   * \param b Symbol to calculate distance
   * \return The distance between symbol \b a and symbol \b b
   *
   * This method returns the distance between symbol \b a and symbol \b b
   */
  float getDistance(char a, char b);

  /** \brief Printing matrix method
   *
   * This method prints the matrix to the standard output
   */
  void printMatrix();
};

#endif
